Django Views - durian.views — durian v0.0.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- durian v0.0.1 documentation »
- Module API Reference »

# Django Views - durian.views

#### Previous topic

Celery Tasks - durian.tasks

#### Next topic

Django Forms - durian.forms

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- modules |
- next |
- previous |
- durian v0.0.1 documentation »
- Module API Reference »

© Copyright 2009, Opera Softare (WebTeam). Created using Sphinx 0.6.3.